@@ -6,10 +6,10 @@ use toluol::DnsType;
 
 #[derive(Debug, PartialEq)]
 pub enum ConnectionType {
-    UDP,
-    TCP,
+    Udp,
+    Tcp,
     #[cfg(feature = "tls")]
-    TLS,
+    Tls,
 }
 
 #[derive(Debug)]
@@ -29,8 +29,8 @@ enum ConsumeNext {
     Port,
 }
 
-const DEFAULT_NAMESERVER: &'static str = "1.1.1.1";
-const DEFAULT_URL: &'static str = "example.com";
+const DEFAULT_NAMESERVER: &str = "1.1.1.1";
+const DEFAULT_URL: &str = "example.com";
 const DEFAULT_QTYPE: DnsType = DnsType::AAAA;
 
 pub fn parse_args() -> Args {
@@ -44,7 +44,7 @@ pub fn parse_args() -> Args {
     #[cfg(feature = "json")]
     let mut json = false;
     let mut use_dnssec = false;
-    let mut connection_type = ConnectionType::UDP;
+    let mut connection_type = ConnectionType::Udp;
     let mut port = None;
 
     let mut reverse = false;
@@ -76,11 +76,11 @@ pub fn parse_args() -> Args {
                     use_dnssec = true;
                 }
                 "tcp" => {
-                    connection_type = ConnectionType::TCP;
+                    connection_type = ConnectionType::Tcp;
                 }
                 #[cfg(feature = "tls")]
                 "tls" => {
-                    connection_type = ConnectionType::TLS;
+                    connection_type = ConnectionType::Tls;
                 }
                 x => {
                     err(format!("Invalid flag: {}.", x));
@@ -151,7 +151,7 @@ pub fn parse_args() -> Args {
     }
 
     #[cfg(feature = "tls")]
-    if connection_type == ConnectionType::TLS {
+    if connection_type == ConnectionType::Tls {
         if webpki::DnsNameRef::try_from_ascii_str(&nameserver).is_err() {
             err("Nameserver must be a valid hostname for TLS.");
         }
