@@ -1051,19 +1051,21 @@ impl DnsRecord {
                 payload_size,
                 edns_version,
                 flags,
-                parsed_rdata,
                 ..
             } => {
                 let mut res = format!("EDNS: Version {}, flags: ", edns_version);
                 res.push_str(if flags["do"] { "do; " } else { "<none>; " });
                 res.push_str(format!("payload size: {}", payload_size).as_str());
 
-                if !parsed_rdata[0].is_empty() {
-                    res.push_str(
-                        format!("; rdata: {}", DnsRecord::format_parsed_rdata(parsed_rdata))
-                            .as_str(),
-                    );
-                }
+                // TODO the parsed rdata format of OPT options is currently not very helpful (just
+                // hex bytes). i've also only seen the padding option in the wild, which we probably
+                // don't want to print anyways.
+                // if !parsed_rdata[0].is_empty() {
+                //     res.push_str(
+                //         format!("; rdata: {}", DnsRecord::format_parsed_rdata(parsed_rdata))
+                //             .as_str(),
+                //     );
+                // }
 
                 res
             }
@@ -1334,7 +1336,7 @@ impl DnsMessage {
 
         let mut res = Vec::new();
         for label in domain.split('.') {
-            if label == "" {
+            if label.is_empty() {
                 // TODO currently we don't validate `domain`. If `label` is not the last label,
                 // this condition should signal an error.
                 continue;
@@ -1431,7 +1433,7 @@ impl Display for DnsMessage {
         let mut res = String::new();
 
         let mut additional_answers = self.additional_answers.clone();
-        let mut opt_index = -1;
+        let mut opt_index = None;
 
         let mut max_owner_len = 0;
         let mut max_type_len = 0;
@@ -1452,8 +1454,7 @@ impl Display for DnsMessage {
                 DnsRecord::OPT { .. } => {
                     // the iterator runs over self.answers, self.authoritative_answers and self.additional_answers,
                     // but we want the index of answer with respect to self.additional_answers
-                    opt_index =
-                        (i - self.answers.len() - self.authoritative_answers.len()) as isize;
+                    opt_index = Some(i - self.answers.len() - self.authoritative_answers.len());
                 }
                 DnsRecord::NONOPT { name, atype, .. } => {
                     max_owner_len = max(max_owner_len, name.len());
@@ -1466,8 +1467,8 @@ impl Display for DnsMessage {
         res.push_str(format!("Header:\n\t{}\n\n", self.header.info_str()).as_str());
 
         // OPT Pseudosection (if present)
-        if opt_index != -1 {
-            let opt = additional_answers.remove(opt_index as usize);
+        if let Some(idx) = opt_index {
+            let opt = additional_answers.remove(idx);
             res.push_str("OPT Pseudosection:\n\t");
             res.push_str(opt.opt_string().as_str());
             res.push_str("\n\n");
