@@ -2,7 +2,7 @@ use anyhow::{bail, Context, Result};
 use byteorder::{NetworkEndian, WriteBytesExt};
 use std::cmp::max;
 use std::io::{Cursor, Read, Write};
-use std::net::{TcpStream, UdpSocket};
+use std::net::{IpAddr, SocketAddr, TcpStream, UdpSocket};
 use std::time::{Duration, Instant};
 use toluol::{DnsFlags, DnsMessage, DnsOpcode, DnsRecord};
 
@@ -30,10 +30,10 @@ fn main() -> Result<()> {
     let data = prepare_query(&args, bufsize)?;
 
     let (answer, bytes_recvd, elapsed) = match args.connection_type {
-        ConnectionType::UDP => send_query_udp(&args, bufsize, &data),
-        ConnectionType::TCP => send_query_tcp(&args, bufsize, &data),
+        ConnectionType::Udp => send_query_udp(&args, bufsize, &data),
+        ConnectionType::Tcp => send_query_tcp(&args, bufsize, &data),
         #[cfg(feature = "tls")]
-        ConnectionType::TLS => send_query_tls(&args, &data),
+        ConnectionType::Tls => send_query_tls(&args, &data),
     }?;
 
     let res = DnsMessage::parse(&mut Cursor::new(&answer)).context("Could not parse answer.")?;
@@ -63,7 +63,7 @@ fn send_query_udp(
     bufsize: u16,
     data: &[u8],
 ) -> Result<(Vec<u8>, u16, Duration)> {
-    let socket = UdpSocket::bind("0.0.0.0:0").context("Could not create UDP socket.")?;
+    let socket = create_and_connect_socket_udp(args)?;
     let mut res = vec![0; bufsize as usize]; // the query sets this as max size
 
     socket
@@ -80,12 +80,12 @@ fn send_query_udp(
 
     let before = Instant::now();
     socket
-        .send(&data)
+        .send(data)
         .context("Could not send data to nameserver")?;
 
     let bytes_recvd = socket
         .recv(&mut res)
-        .context("The server did not reply in time.")?;
+        .context("The nameserver did not reply in time.")?;
     let elapsed = before.elapsed();
 
     res.resize(bytes_recvd, 0);
@@ -93,6 +93,41 @@ fn send_query_udp(
     Ok((res, bytes_recvd as u16, elapsed))
 }
 
+fn create_and_connect_socket_udp(args: &args::Args) -> Result<UdpSocket> {
+    if let Ok(ns_addr) = args.nameserver.parse::<IpAddr>() {
+        // must match the IP protocol version of ns_addr, else we get an "Address family not
+        // supported by protocol" error on connect()
+        let bind_addr = if ns_addr.is_ipv6() { "::" } else { "0.0.0.0" };
+        let connect_addr: SocketAddr = (ns_addr, args.port).into();
+        let socket = UdpSocket::bind((bind_addr, 0)).context("Could not create UDP socket.")?;
+        socket
+            .connect(connect_addr)
+            .context(format!("Could not connect to {} via UDP.", connect_addr))?;
+        Ok(socket)
+    } else {
+        // treat args.nameserver as a hostname. first try to connect via IPv6; if that fails, try
+        // IPv4; if that also fails, bail.
+
+        let connect_addr = format!("{}:{}", args.nameserver, args.port);
+        // tried in reverse, i.e. "::" is tried first
+        let mut bind_addrs = vec!["0.0.0.0", "::"];
+        let mut socket = None;
+        while socket.is_none() && !bind_addrs.is_empty() {
+            let bind_addr = bind_addrs.pop().unwrap();
+            let sock = UdpSocket::bind((bind_addr, 0)).context("Could not create UDP socket.")?;
+            if sock.connect(&connect_addr).is_ok() {
+                socket = Some(sock);
+            }
+        }
+
+        if let Some(sock) = socket {
+            Ok(sock)
+        } else {
+            Err(anyhow!("Could not connect to {} via UDP.", connect_addr))
+        }
+    }
+}
+
 fn send_query_tcp(
     args: &args::Args,
     bufsize: u16,
@@ -258,7 +293,7 @@ fn display_result(res: &DnsMessage, args: &args::Args, bytes_recvd: u16, elapsed
         println!("Query metadata:");
         println!("\tTime:        {} ms", elapsed.as_millis());
         println!("\tReply size:  {} bytes", bytes_recvd);
-        println!("\tServer:      {}:{}", args.nameserver, args.port);
+        println!("\tServer:      {}#{}", args.nameserver, args.port);
         return;
     }
 
